@@ -1,5 +1,5 @@
 package App::XML::DocBook::Docmake;
-
+$App::XML::DocBook::Docmake::VERSION = '0.0405';
 use strict;
 use warnings;
 
@@ -11,19 +11,6 @@ use Pod::Usage;
 
 use parent 'Class::Accessor';
 
-=head1 NAME
-
-App::XML::DocBook::Docmake - translate DocBook/XML to other formats
-
-=head1 VERSION
-
-Version 0.0404
-
-=cut
-
-use vars qw($VERSION);
-
-$VERSION = '0.0404';
 
 __PACKAGE__->mk_accessors(qw(
     _base_path
@@ -39,21 +26,6 @@ __PACKAGE__->mk_accessors(qw(
     _xslt_stringparams
 ));
 
-=head1 SYNOPSIS
-
-    use App::XML::DocBook::Docmake;
-
-    my $docmake = App::XML::DocBook::Docmake->new({argv => [@ARGV]});
-
-    $docmake->run()
-
-=head1 FUNCTIONS
-
-=head2 my $obj = App::XML::DocBook::Docmake->new({argv => [@ARGV]})
-
-Instantiates a new object.
-
-=cut
 
 my %modes =
 (
@@ -190,11 +162,6 @@ sub _init
     return;
 }
 
-=head2 $docmake->run()
-
-Runs the object.
-
-=cut
 
 sub _exec_command
 {
@@ -228,7 +195,7 @@ sub _run_mode_help
     my $self = shift;
 
     print <<"EOF";
-Docmake version $VERSION
+Docmake version $App::XML::DocBook::Docmake::VERSION
 A tool to convert DocBook/XML to other formats
 
 Available commands:
@@ -572,7 +539,7 @@ sub _output_cmd_comp
 }
 
 package App::XML::DocBook::Docmake::CmdComponent;
-
+$App::XML::DocBook::Docmake::CmdComponent::VERSION = '0.0405';
 use base 'Class::Accessor';
 
 __PACKAGE__->mk_accessors(qw(
@@ -582,6 +549,45 @@ __PACKAGE__->mk_accessors(qw(
 
 1;
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+App::XML::DocBook::Docmake - translate DocBook/XML to other formats
+
+=head1 VERSION
+
+version 0.0405
+
+=head1 SYNOPSIS
+
+    use App::XML::DocBook::Docmake;
+
+    my $docmake = App::XML::DocBook::Docmake->new({argv => [@ARGV]});
+
+    $docmake->run()
+
+=head1 VERSION
+
+version 0.0405
+
+=head1 FUNCTIONS
+
+=head2 my $obj = App::XML::DocBook::Docmake->new({argv => [@ARGV]})
+
+Instantiates a new object.
+
+=head2 $docmake->run()
+
+Runs the object.
+
 =head1 AUTHOR
 
 Shlomi Fish, C<< <shlomif at cpan.org> >>
@@ -631,7 +637,132 @@ Copyright 2008 Shlomi Fish.
 This program is released under the following license: MIT/X11 License.
 ( L<http://www.opensource.org/licenses/mit-license.php> ).
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2018 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/app-xml-docbook-builder/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc App::XML::DocBook::Docmake
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/App-XML-DocBook-Builder>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/App-XML-DocBook-Builder>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-XML-DocBook-Builder>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/App-XML-DocBook-Builder>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/App-XML-DocBook-Builder>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/App-XML-DocBook-Builder>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/A/App-XML-DocBook-Builder>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=App-XML-DocBook-Builder>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=App::XML::DocBook::Builder>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-app-xml-docbook-builder at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=App-XML-DocBook-Builder>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/app-xml-docbook-builder>
+
+  git clone http://bitbucket.org/shlomif/docmake
+
 =cut
-
-1;
-
